@@ -20,9 +20,10 @@
  * USA.
  */
 #include "ibus-chewing-engine.h"
-#include "IBusChewingPreEdit.h"
-#include "IBusChewingUtil.h"
-#include "MakerDialogUtil.h"
+#include "ibus-chewing-preedit.h"
+#include "ibus-chewing-lookup-table.h"
+#include "ibus-chewing-util.h"
+#include "maker-dialog-util.h"
 #include "ibus-chewing-engine-private.h"
 #include <chewing.h>
 #include <glib.h>
@@ -753,7 +754,7 @@ void ibus_chewing_engine_start(IBusChewingEngine *self) {
  */
 void ibus_chewing_engine_reset(IBusEngine *engine) {
     IBusChewingEngine *self = IBUS_CHEWING_ENGINE(engine);
-    IBUS_CHEWING_LOG(MSG, "* reset");
+    IBUS_CHEWING_LOG(MSG, "* reset()");
 
     /* Always clean buffer */
     ibus_chewing_pre_edit_clear(self->icPreEdit);
@@ -832,41 +833,32 @@ void ibus_chewing_engine_set_content_type(IBusEngine *engine, guint purpose, gui
  *
  */
 
-void parent_commit_text(IBusEngine *iEngine) {
+static void parent_commit_text(IBusEngine *iEngine) {
     IBusChewingEngine *self = IBUS_CHEWING_ENGINE(iEngine);
 
     IBUS_CHEWING_LOG(MSG, "* parent_commit_text(-): outgoingText=%s", self->outgoingText->text);
 #ifdef UNIT_TEST
-    printf("* parent_commit_text(-, %s)\n", self->outgoingText->text);
+    printf("# * parent_commit_text(-, %s)\n", self->outgoingText->text);
 #else
     ibus_engine_commit_text(iEngine, self->outgoingText);
 #endif
 }
 
-void parent_update_pre_edit_text([[maybe_unused]] IBusEngine *iEngine, IBusText *iText,
-                                 guint cursor_pos, gboolean visible) {
+static void parent_update_pre_edit_text_with_mode([[maybe_unused]] IBusEngine *iEngine,
+                                                  IBusText *iText, guint cursor_pos,
+                                                  gboolean visible, IBusPreeditFocusMode mode) {
 #ifdef UNIT_TEST
-    printf("* parent_update_pre_edit_text(-, %s, %u, %x)\n", iText->text, cursor_pos, visible);
-#else
-    ibus_engine_update_preedit_text(iEngine, iText, cursor_pos, visible);
-#endif
-}
-
-void parent_update_pre_edit_text_with_mode([[maybe_unused]] IBusEngine *iEngine, IBusText *iText,
-                                           guint cursor_pos, gboolean visible,
-                                           IBusPreeditFocusMode mode) {
-#ifdef UNIT_TEST
-    printf("* parent_update_pre_edit_text_with_mode(-, %s, %u, %x, %x)\n", iText->text, cursor_pos,
+    printf("# * parent_update_pre_edit_text_with_mode(-, %s, %u, %x, %x)\n", iText->text, cursor_pos,
            visible, mode);
 #else
     ibus_engine_update_preedit_text_with_mode(iEngine, iText, cursor_pos, visible, mode);
 #endif
 }
 
-void parent_update_auxiliary_text([[maybe_unused]] IBusEngine *iEngine, IBusText *iText,
-                                  gboolean visible) {
+static void parent_update_auxiliary_text([[maybe_unused]] IBusEngine *iEngine, IBusText *iText,
+                                         gboolean visible) {
 #ifdef UNIT_TEST
-    printf("* parent_update_auxiliary_text(-, %s, %x)\n", (iText) ? iText->text : "NULL", visible);
+    printf("# * parent_update_auxiliary_text(-, %s, %x)\n", (iText) ? iText->text : "NULL", visible);
 #else
     if (!visible || ibus_text_is_empty(iText)) {
         ibus_engine_hide_auxiliary_text(iEngine);
@@ -877,8 +869,8 @@ void parent_update_auxiliary_text([[maybe_unused]] IBusEngine *iEngine, IBusText
 #endif
 }
 
-IBusText *decorate_pre_edit(IBusChewingPreEdit *icPreEdit,
-                            [[maybe_unused]] IBusCapabilite capabilite) {
+static IBusText *decorate_pre_edit(IBusChewingPreEdit *icPreEdit,
+                                   [[maybe_unused]] IBusCapabilite capabilite) {
     gchar *preEdit = ibus_chewing_pre_edit_get_pre_edit(icPreEdit);
     IBusText *iText = ibus_text_new_from_string(preEdit);
     gint chiSymbolCursor = chewing_cursor_Current(icPreEdit->context);
@@ -1101,7 +1093,7 @@ void ibus_chewing_engine_property_activate(IBusEngine *engine, const gchar *prop
         ibus_chewing_engine_refresh_property(self, prop_name);
     } else if (STRING_EQUALS(prop_name, "setup_prop")) {
         /* open preferences window */
-        char *argv[] = { QUOTE_ME(LIBEXEC_DIR) "/ibus-setup-chewing", NULL };
+        char *argv[] = {QUOTE_ME(LIBEXEC_DIR) "/ibus-setup-chewing", NULL};
         g_spawn_async(NULL, argv, NULL, G_SPAWN_DEFAULT, NULL, NULL, NULL, NULL);
     } else {
         IBUS_CHEWING_LOG(DEBUG, "property_activate(-, %s, %u) not recognized", prop_name,
