@@ -22,8 +22,8 @@
 
 #pragma once
 
-#include "IBusChewingPreEdit.h"
-#include "IBusChewingUtil.h"
+#include "ibus-chewing-preedit.h"
+#include "ibus-chewing-util.h"
 #include <glib-object.h>
 #include <glib.h>
 #include <ibus.h>
@@ -64,4 +64,4 @@ gboolean ibus_chewing_engine_use_system_layout(IBusChewingEngine *self);
 void ibus_chewing_engine_notify_chinese_english_mode_change(IBusChewingEngine *self);
 void ibus_chewing_engine_notify_fullwidth_mode_change(IBusChewingEngine *self);
 
-G_END_DECLS
\ No newline at end of file
+G_END_DECLS
